@@ -12,7 +12,7 @@ our $VERSION = 0.001_000;
 # [[[ OPERATIONS ]]]
 
 our void $foo = sub {
-    ( my string $bar ) = @_;
+    ( my string $bar ) = @ARG;
     print $bar, "\n";
 };
 foo('howdy!');
