@@ -11,8 +11,7 @@ our $VERSION = 0.001_000;
 
 # [[[ OPERATIONS ]]]
 
-foreach my string $key (
-    sort keys %{ { a => 10, b => 20, c => 30, d => 40, e => 50 } } )
+foreach my string $key ( sort keys %{ { a => 10, b => 20, c => 30, d => 40, e => 50 } } )
 {
     print '$key = ', $key, "\n";
 }
