@@ -1,8 +1,8 @@
 #!/usr/bin/perl
 
 # [[[ PREPROCESSOR ]]]
-# <<< PARSE_ERROR: 'ERROR ECVPARP00' >>>
-# <<< PARSE_ERROR: 'Unexpected Token:  }' >>>
+# <<< PARSE_ERROR: 'ERROR ECOPARP00' >>>
+# <<< PARSE_ERROR: 'Unexpected Token:  50' >>>
 
 # [[[ HEADER ]]]
 use RPerl;
@@ -13,8 +13,10 @@ our $VERSION = 0.001_000;
 # [[[ CRITICS ]]]
 ## no critic qw(ProhibitUselessNoCritic ProhibitMagicNumbers RequireCheckedSyscalls)  # USER DEFAULT 1: allow numeric values & print operator
 ## no critic qw(RequireInterpolationOfMetachars)  # USER DEFAULT 2: allow single-quoted control characters & sigils
+## no critic qw(ProhibitCStyleForLoops)  # USER DEFAULT 6: allow C-style for() loop headers
 
 # [[[ OPERATIONS ]]]
 
-TESTFOREACHLOOP:
-foreach my number $my_number ( 1.1, 2.2, 3.3, 4.4 ) { }
+for ( my integer $i = 1; 50 > $i; $i = $i * 2 ) {
+    print 'Production rule Loop matched by C-Style LoopFor, iteration number ', $i, "\n";
+}
